@@ -26,3 +26,6 @@ def mysqldump(dir='hosting/backups'):
     with cd(env.conf['SRC_DIR']):
         run('mysqldump -uroot -p%s %s > %s/%s%s.sql' % (password, db, dir, db, now))
 
+def delete_pyc():
+    with cd(env.conf['SRC_DIR']):
+        run("find . -name '*.pyc' -delete")
